---
name: Bug report
about: Create a report to help us improve polyply
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is and mention the polyply version.
To find the version run `polyply --version`

**Command line arguments**
Provide all polyply calls and arguments needed to reproduce the issue:
```
polyply gen_seq ...
polyply gen_itp ...
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Additional Files**
If applicable, add all files needed in the reproduction.
